//+------------------------------------------------------------------+
//|                                                ACD Indicator.mq5 |
//|                                                      Mighty Algo |
//|                                        http://www.MightyAlgo.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2019, Mighty Algo."
#property link      "http://www.MightyAlgo.com"
#property version   "1.00"

#include    <MightyAlgo/ACD/OR_Times.mqh>

#property indicator_chart_window
#property indicator_buffers 8
#property indicator_plots   8
//--- plot ORHigh
#property indicator_label1  "ORHigh"
#property indicator_type1   DRAW_LINE
#property indicator_color1  clrAqua
#property indicator_style1  STYLE_DASHDOT
#property indicator_width1  1
//--- plot ORLow
#property indicator_label2  "ORLow"
#property indicator_type2   DRAW_LINE
#property indicator_color2  clrAqua
#property indicator_style2  STYLE_DASHDOT
#property indicator_width2  1
//--- plot AUP
#property indicator_label3  "AUP"
#property indicator_type3   DRAW_LINE
#property indicator_color3  clrAqua
#property indicator_style3  STYLE_SOLID
#property indicator_width3  1
//--- plot ADown
#property indicator_label4  "ADown"
#property indicator_type4   DRAW_LINE
#property indicator_color4  clrAqua
#property indicator_style4  STYLE_SOLID
#property indicator_width4  1
//--- plot CUP
#property indicator_label5  "CUP"
#property indicator_type5   DRAW_LINE
#property indicator_color5  clrNavy
#property indicator_style5  STYLE_SOLID
#property indicator_width5  1
//--- plot CDown
#property indicator_label6  "CDown"
#property indicator_type6   DRAW_LINE
#property indicator_color6  clrNavy
#property indicator_style6  STYLE_SOLID
#property indicator_width6  1
//--- ATR Up
#property indicator_label7  "ATRUp"
#property indicator_type7   DRAW_LINE
#property indicator_color7  clrYellowGreen
#property indicator_style7  STYLE_DASHDOTDOT
#property indicator_width7  1
//--- ATR Down
#property indicator_label8  "ATRDown"
#property indicator_type8   DRAW_LINE
#property indicator_color8  clrYellowGreen
#property indicator_style8  STYLE_DASHDOTDOT
#property indicator_width8  1

//--- indicator buffers
double         ORHighBuffer[];
double         ORLowBuffer[];
double         AUPBuffer[];
double         ADownBuffer[];
double         CUPBuffer[];
double         CDownBuffer[];
double         ATRUpBuffer[];
double         ATRDownBuffer[];

input bool     predef=true;   // Predefined
input string   orst="16:00";  // OR Start 
input string   oren="16:15";  // OR END 
input string   ortr="23:00";  // OR Treminate
input int      days=500;      // Number of Days Show
//--- Variables
int      handle;
OR_Res   symb;
string   StartRange, EndRange, EndPeriod;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit()
  {
// ChartSetSymbolPeriod(0,NULL,PERIOD_M5);
   if(predef)
     {
      symb=          OR_Times(_Symbol);
      StartRange=    symb.OR_start_time;
      EndRange=      symb.OR_end_time;
      EndPeriod=     symb.OR_terminate;
     }
   else
     {
      StartRange=    orst;
      EndRange=      oren;
      EndPeriod=     ortr;
     }



//--- indicator buffers mapping
   SetIndexBuffer(0,ORHighBuffer,INDICATOR_DATA);
   SetIndexBuffer(1,ORLowBuffer,INDICATOR_DATA);
   SetIndexBuffer(2,AUPBuffer,INDICATOR_DATA);
   SetIndexBuffer(3,ADownBuffer,INDICATOR_DATA);
   SetIndexBuffer(4,CUPBuffer,INDICATOR_DATA);
   SetIndexBuffer(5,CDownBuffer,INDICATOR_DATA);
   SetIndexBuffer(6,ATRUpBuffer,INDICATOR_DATA);
   SetIndexBuffer(7,ATRDownBuffer,INDICATOR_DATA);
   handle=iATR(NULL,PERIOD_D1,10);


   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
double max,min,DailyAtr[],dailyatr;
string barTime,today,activeday;
int newj,j,to_copy,limit;
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {
   int first=14;
   CopyBuffer(handle,0,0,rates_total,DailyAtr);
   ArraySetAsSeries(DailyAtr,true);


   if(prev_calculated>0)
      first=prev_calculated-1;
   for(int i=first; i<rates_total; i++)
     {
      ORHighBuffer[i]=EMPTY_VALUE;
      ORLowBuffer[i]=EMPTY_VALUE;
      AUPBuffer[i]=EMPTY_VALUE;
      ADownBuffer[i]=EMPTY_VALUE;
      CUPBuffer[i]=EMPTY_VALUE;
      CDownBuffer[i]=EMPTY_VALUE;
      ATRUpBuffer[i]=EMPTY_VALUE;
      ATRDownBuffer[i]=EMPTY_VALUE;

      today=TimeToString(time[i],TIME_DATE);
      string currentday=TimeToString(TimeCurrent()-30*60*60*days,TIME_DATE);
      if(today>currentday)
        {
         barTime = TimeToString(time[i],TIME_MINUTES);
         if(barTime==EndPeriod || today!=activeday)
           {
            min=900000000;
            max=0;
            activeday=today;
           }
         if(barTime>=StartRange && barTime<EndRange)
           {
            if(high[i]>max)
               max=high[i];
            if(low[i]<min)
               min=low[i];
            j=iBarShift(NULL,PERIOD_D1,time[i],true);
            dailyatr=DailyAtr[j+1];
           }

         //----Drawing
         if(barTime>=EndRange && barTime<EndPeriod)
           {
            ORHighBuffer[i]=max;
            ORLowBuffer[i]=min;
            AUPBuffer[i]=max+dailyatr*0.06;
            ADownBuffer[i]=min-dailyatr*0.06;
            CUPBuffer[i]=max+dailyatr*0.09;
            CDownBuffer[i]=min-dailyatr*0.09;
            ATRUpBuffer[i]=min+dailyatr;
            ATRDownBuffer[i]=max-dailyatr;
            if(ORHighBuffer[i]>=AUPBuffer[i])
               return(0);
           }
        }
     }
   ChartRedraw();
//--- return value of prev_calculated for next call
   return(rates_total);
  }
//+------------------------------------------------------------------+
